Key Pairs are how you login to your instance after it is launched. Choose a key pair name you will recognize and paste your SSH public key into the space provided.

There are two ways to generate a key pair. From a Linux system, generate the key pair with the `ssh-keygen` command:

`ssh-keygen -t rsa -f cloud.key`

This command generates a pair of keys: a private key (cloud.key) and a public key (cloud.key.pub).

From a Windows system, you can use PuTTYGen to create private/public keys. Use the PuTTY Key Generator to create and save the keys, then copy the public key in the red highlighted box to your `.ssh/authorized_keys` file.